==> vdr-cecremote-debug-1.5.0-10-x86_64.pkg.tar.zst: usr/src/debug/vdr-cecremote/cecremote-1.5.0/statusmonitor.cc <==
/*
 * CECRemote PlugIn for VDR
 *
 * Copyright (C) 2015-2019 Ulrich Eckhardt <uli-vdr@uli-eckhardt.de>
 *
 * This code is distributed under the terms and conditions of the
 * GNU GENERAL PUBLIC LICENSE. See the file COPYING for details.
 *
 * This class implements the status monitor for channel switch information.
 */

#include "statusmonitor.h"
#include "ceclog.h"
#include "ceccontrol.h"

namespace cecplugin {

cStatusMonitor::cStatusMonitor(cPluginCecremote *plugin) : mMonitorStatus(UNKNOWN) {
    mPlugin = plugin;
    mVolume = -1;
}

cStatusMonitor::~cStatusMonitor() {

}

void cStatusMonitor::ChannelSwitch(const cDevice *Device, int ChannelNumber,
                                   bool LiveView)
{
    char l = 'f';
    if (LiveView) {
        l = 't';
    }
    if (Device->IsPrimaryDevice()) {
        Dsyslog("Primary device, Channel Switch %d %c", ChannelNumber,l);
#if (APIVERSNUM >= 20301)
        LOCK_CHANNELS_READ;
        const cChannel* channel = Channels->GetByNumber(ChannelNumber);
#else
        const cChannel* channel = Channels.GetByNumber(ChannelNumber);
#endif
        if (channel != NULL) {
            if (channel->Vpid() == 0) {
                Dsyslog("  Radio : %s", channel->Name());
                if (mMonitorStatus != RADIO) {
                    // Ignore first switch, this is covered by <onstart>
                    if (mMonitorStatus != UNKNOWN) {
                        mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.
                                              mGlobalOptions.mOnSwitchToRadio);
                    }
                    mMonitorStatus = RADIO;
                }
            }
            else {
                Dsyslog("  TV    : %s", channel->Name());
                if (mMonitorStatus != TV) {
                    // Ignore first switch, this is covered by <onstart>
                    if (mMonitorStatus != UNKNOWN) {
                        mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.
                                              mGlobalOptions.mOnSwitchToTV);
                    }
                    mMonitorStatus = TV;
                }
            }
        }
        Csyslog("Channel switch OK");
    }
    else {
        Dsyslog("Not primary device, Channel Switch %d %c", ChannelNumber, l);
    }
}

void cStatusMonitor::Replaying(const cControl *Control, const char *Name,
                               const char *FileName, bool On)
{
    Dsyslog("Replaying");
    if (On) {
        if (mMonitorStatus != REPLAYING) {
            mMonitorStatus = REPLAYING;
            mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.mGlobalOptions.mOnSwitchToReplay);
        }
    }
}

void cStatusMonitor::SetVolume(int Volume, bool Absolute)
{
    cCECMenu menuitem;
    int newvol = 128;
    Dsyslog("SetVolume %d %d", Volume, Absolute);
    if (mVolume > 0) {
        newvol = mVolume;
    }
    if (!Absolute) {
        newvol += Volume;
    }
    else {
        newvol = Volume;
    }
    // Always ignore first call.
    if (mVolume == -1) {
        mVolume = newvol;
        return;
    }

    cControl *c = cControl::Control();
    if (c == NULL) {
        return;
    }
    cCECControl *cont = dynamic_cast<cCECControl*>(c);
    if (cont == NULL) {
        return;
    }
    Dsyslog("Stillpic Player running %s", cont->getMenuTitle().c_str());
    menuitem = cont->getConfig();
    if (newvol > mVolume) {
        mPlugin->PushCmdQueue(menuitem.mOnVolumeUp);
    }
    else {
        mPlugin->PushCmdQueue(menuitem.mOnVolumeDown);
    }
    mVolume = newvol;
}

} // namespace cecplugin

==> vdr-cecremote-debug-1.5.1-1-x86_64.pkg.tar.zst: usr/src/debug/vdr-cecremote/cecremote-1.5.1/statusmonitor.cc <==
/*
 * CECRemote PlugIn for VDR
 *
 * Copyright (C) 2015-2024 Ulrich Eckhardt <uli-vdr@uli-eckhardt.de>
 *
 * This code is distributed under the terms and conditions of the
 * GNU GENERAL PUBLIC LICENSE. See the file COPYING for details.
 *
 * This class implements the status monitor for channel switch information.
 */

#include "statusmonitor.h"
#include "ceclog.h"
#include "ceccontrol.h"

namespace cecplugin {

cStatusMonitor::cStatusMonitor(cPluginCecremote *plugin) : mMonitorStatus(UNKNOWN) {
    mPlugin = plugin;
    mVolume = -1;
}

cStatusMonitor::~cStatusMonitor() {

}

void cStatusMonitor::ChannelSwitch(const cDevice *Device, int ChannelNumber,
                                   bool LiveView)
{
    char l = 'f';
    if (LiveView) {
        l = 't';
    }
    if (Device->IsPrimaryDevice()) {
        Dsyslog("Primary device, Channel Switch %d %c", ChannelNumber,l);
#if (APIVERSNUM >= 20301)
        LOCK_CHANNELS_READ;
        const cChannel* channel = Channels->GetByNumber(ChannelNumber);
#else
        const cChannel* channel = Channels.GetByNumber(ChannelNumber);
#endif
        if (channel != NULL) {
            if (channel->Vpid() == 0) {
                Dsyslog("  Radio : %s", channel->Name());
                if (mMonitorStatus != RADIO) {
                    // Ignore first switch, this is covered by <onstart>
                    if (mMonitorStatus != UNKNOWN) {
                        mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.
                                              mGlobalOptions.mOnSwitchToRadio);
                    }
                    mMonitorStatus = RADIO;
                }
            }
            else {
                Dsyslog("  TV    : %s", channel->Name());
                if (mMonitorStatus != TV) {
                    // Ignore first switch, this is covered by <onstart>
                    if (mMonitorStatus != UNKNOWN) {
                        mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.
                                              mGlobalOptions.mOnSwitchToTV);
                    }
                    mMonitorStatus = TV;
                }
            }
        }
        Csyslog("Channel switch OK");
    }
    else {
        Dsyslog("Not primary device, Channel Switch %d %c", ChannelNumber, l);
    }
}

void cStatusMonitor::Replaying(const cControl *Control, const char *Name,
                               const char *FileName, bool On)
{
    Dsyslog("Replaying");
    if (On) {
        if (mMonitorStatus != REPLAYING) {
            mMonitorStatus = REPLAYING;
            mPlugin->PushCmdQueue(mPlugin->mConfigFileParser.mGlobalOptions.mOnSwitchToReplay);
        }
    }
}

void cStatusMonitor::SetVolume(int Volume, bool Absolute)
{
    cCECMenu menuitem;
    int newvol = 128;
    Dsyslog("SetVolume %d %d", Volume, Absolute);
    if (mVolume > 0) {
        newvol = mVolume;
    }
    if (!Absolute) {
        newvol += Volume;
    }
    else {
        newvol = Volume;
    }
    // Always ignore first call.
    if (mVolume == -1) {
        mVolume = newvol;
        return;
    }

    cMutexLock lock;
    cControl *c = cControl::Control(lock);
    if (c == NULL) {
        return;
    }
    cCECControl *cont = dynamic_cast<cCECControl*>(c);
    if (cont == NULL) {
        return;
    }
    Dsyslog("Stillpic Player running %s", cont->getMenuTitle().c_str());
    menuitem = cont->getConfig();
    if (newvol > mVolume) {
        mPlugin->PushCmdQueue(menuitem.mOnVolumeUp);
    }
    else {
        mPlugin->PushCmdQueue(menuitem.mOnVolumeDown);
    }
    mVolume = newvol;
}

} // namespace cecplugin
